#
# spec file for package bladeRF
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2013-2015 Wojciech Kazubski, wk@ire.pw.edu.pl
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover 2
%define libname lib%{name}%{sover}
%define libversion 2.5.0
%define release_name 2023.02
%define bladerf_group bladerf
%define use_syslog 0
Name:           bladeRF
Version:        2023.02
Release:        16.5
Summary:        SDR radio receiver
License:        AGPL-3.0-or-later AND GPL-2.0-only
Group:          Productivity/Hamradio/Other
URL:            https://nuand.com/
#Git-Clone:     https://github.com/Nuand/bladeRF.git
Source0:        https://github.com/Nuand/bladeRF/archive/%{release_name}.tar.gz#/%{name}-%{release_name}.tar.xz
Source1:        ad9361.tar.xz
Patch0:         bladeRF-doxygen-no-timestamp.patch
BuildRequires:  cmake >= 2.8.4
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  git-core
BuildRequires:  help2man
BuildRequires:  pkgconfig
BuildRequires:  tecla-devel
BuildRequires:  pkgconfig(libedit)
BuildRequires:  pkgconfig(libusb-1.0)
BuildRequires:  pkgconfig(udev)

%description
The software for bladeRF USB 3.0 Superspeed Software Defined Radio.

%package -n %{libname}
Summary:        SDR radio receiver library
Group:          System/Libraries
Version:        %{libversion}
Release:        16.5
Requires:       %{name}-udev

%description -n %{libname}
Library for bladeRF, an SDR transceiver.

%package -n %{libname}-doc
Summary:        Documentation for libbladeRF
Group:          Documentation/HTML
Version:        %{libversion}
Release:        16.5

%description -n %{libname}-doc
HTML documentation files for libbladeRF.

%package udev
Summary:        Udev rules for bladeRF
Group:          Hardware/Other
Requires(pre):  shadow

%description udev
Udev rules for bladeRF.

%package devel
Summary:        Development files for libbladeRF
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{libversion}

%description devel
Libraries and header files for developing applications that want to make
use of libbladerf.

%prep
%setup -q -n %{name}-%{release_name}
%patch0 -p1
ls
pushd thirdparty/analogdevicesinc/no-OS
tar -xJf %{SOURCE1}
popd

%build
cd host
%cmake \
  -DVERSION_INFO_EXTRA="" \
  -DCMAKE_INSTALL_LIBDIR:PATH=%{_lib} \
  -DUDEV_RULES_PATH=%{_udevrulesdir} \
  -DBLADERF_GROUP=%{bladerf_group} \
%if 0%{?use_syslog}
  -DENABLE_LIBBLADERF_SYSLOG=ON \
%endif
  -DBUILD_DOCUMENTATION=ON
%cmake_build

%install
cd host
%cmake_install

#move docs
mkdir -p %{buildroot}%{_docdir}
mv %{buildroot}/%{_datadir}/doc/libbladeRF %{buildroot}%{_docdir}

%post -n %{libname} -p /sbin/ldconfig
%postun  -n %{libname} -p /sbin/ldconfig

%pre udev
getent group %{bladerf_group} >/dev/null || groupadd -r %{bladerf_group}

%post udev
%udev_rules_update

%postun udev
%udev_rules_update

%files
%license COPYING
%doc README.md CONTRIBUTORS
%{_bindir}/bladeRF-cli
%{_bindir}/bladeRF-fsk
%{_mandir}/man1/bladeRF-cli.1%{?ext_man}

%files udev
%{_udevrulesdir}/88-nuand-*.rules

%files -n %{libname}
%{_libdir}/libbladeRF.so.%{sover}*

%files -n %{libname}-doc
%{_docdir}/libbladeRF

%files devel
%{_libdir}/libbladeRF.so
%{_includedir}/bladeRF1.h
%{_includedir}/bladeRF2.h
%{_includedir}/libbladeRF.h
%{_libdir}/pkgconfig/libbladeRF.pc

%changelog
* Mon Feb 13 2023 Martin Hauke <mardnh@gmx.de>
- Update to version 2023.02
  * libbladeRF
    + Add 8bit format mode support
    + Add AD936x overclocking feature
    + Fix bugs, including a locking bug
  * FPGA:
    + Add 8bit mode support to FIFO reader and writer
- Add patch:
  * bladeRF-doxygen-no-timestamp.patch
* Sat Jan 22 2022 Martin Hauke <mardnh@gmx.de>
- Don't set VERSION_INFO_EXTRA to strip "-git-unknown" from the
  libbladeRF version (e.g. "2.4.1-git-unknown" -> "2.4.1")
* Tue Oct  5 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 2021.10
  * Fix up packet mode bugs
  * Add Wishbone master core as NiOS peripheral
* Tue Sep 21 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 2021.09
  * Support new keywords in config file for bladerf2.0 clocking:
    + Update doc for new keywords
    + Add clock_out keyword
    + Add clock_sel keyword
    + Add refin_freq keyword
    + Add clock_ref keyword
    + Fix parsing of vctcxo_tamer key
  * Python bindings: Fix get_gain_modes
  * Make all of the get_*_range functions work
  * Revert "hdl: bladerf-wlan: disable RX switch when tx_ota_req
    is asserted"
* Tue Feb 16 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 2021.03
  * cyapi: add META support to cyapi backend
* Sat Feb 13 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 2021.02
  Bugfix release
  * Revert "ad936x_params: allow CTRL_IN to control gain in MGC
    mode"
* Fri Jan 15 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 2020.12
  libbladeRF
  * Added packet mode format BLADERF_FORMAT_PACKET_META.
    libbladeRF is able to exchange variable length packets with
    the HDL if packet mode is enabled
  * Added RFIC parameters for burst waveforms
  * Ability to query backend for handle and lock FX3
  * Variable length packet support for PACKET_META mode
  bladeRF-cli:
  * Indicate presence of packet cores in FPGA
  Python
  * Update for libbladeRF v2.4.0
- Drop patches (integrated upstream):
  * 0001-libbladeRF-unambiguous-flash_arch-macro-name.patch
  * 0002-libbladeRF-define-bladerf2_state_to_string-as-extern.patch
* Sun Jun  7 2020 Martin Hauke <mardnh@gmx.de>
- Add patches to fix gcc10 compile errors:
  * 0001-libbladeRF-unambiguous-flash_arch-macro-name.patch
  * 0002-libbladeRF-define-bladerf2_state_to_string-as-extern.patch
* Fri Jan 17 2020 Martin Hauke <mardnh@gmx.de>
- Redownloaded tarball
* Tue Aug 27 2019 Jan Engelhardt <jengelh@inai.de>
- Update summaries and RPM category groups.
* Tue Aug 27 2019 Martin Pluskal <mpluskal@suse.com>
- Fix download url
- Small packaging enhancements
* Sat Aug 17 2019 Wojciech Kazubski <wk@ire.pw.edu.pl>
- Update to version 2019.07
  libbladeRF
  * Gain mode setting default is now manual
  * Tuning mode setting default is now host
  * Add OTP command support
  * Fix metadata related arithmetic
  bladeRF-cli:
  * Add RFIC fitler selection
  * Add tuning_mode
  * Display more useful warning and error messages
- libbladeRF doc files (HTML) in separate package
* Fri Sep  7 2018 Martin Pluskal <mpluskal@suse.com>
- Clarify license status
* Wed Sep  5 2018 mardnh@gmx.de
- Update to version 2018.08
  libbladeRF
  * Added support for Automatic Gain Control
  * Added bladeRF.conf config option file
  * Refactor to support for multiple product lines
  * Add support for the bladeRF Micro product
  * API: replace bladerf_module with bladerf_channel, a reverse-compatible
  * change to handle products with multiple independent RF paths in the same
  * direction
  * API: BREAKING CHANGE - on bladerf_set_frequency, et al, the frequency
  * parameter is now uint64_t instead of unsigned int
  * Add typedefs for common param types, e.g. bladerf_frequency -> uint64_t
  bladeRF-cli
  * Added support for Automatic Gain Control
  * No longer initializes the bladeRF before loading a new FPGA image, to
  * avoid potential catch-22 problems
  * bladeRF 2.0 Micro support
  * Support for MIMO RX and TX using "channel=" parameter on rx/tx config
  * Various code quality fixups
- Remove patches: (fixed upstream)
  * bladeRF-add-cflag-Wno-format-truncation.patch
  * bladeRF-cmake_syntax.patch
* Tue Sep  5 2017 mpluskal@suse.com
- Fix cmake syntax error:
  * bladeRF-cmake_syntax.patch
* Thu Jun  1 2017 mardnh@gmx.de
- Add patch:
  * bladeRF-add-cflag-Wno-format-truncation.patch (boo#1041192)
* Wed Apr 26 2017 mardnh@gmx.de
- build with support for libtecla
* Sun Apr 23 2017 mardnh@gmx.de
- Update group handling
* Thu Apr 20 2017 mpluskal@suse.com
- Update group handling
* Sat Apr 15 2017 mardnh@gmx.de
- Workaround for generating manpages/documentation on
  systems emulated via qemu (arm, ppc,...) not longer needed
* Sat Apr 15 2017 mardnh@gmx.de
- Adjust Source-URL
- Use proper cmake options
- Use group bladerf in the udev-rules
* Thu Mar 30 2017 wk@ire.pw.edu.pl
- fixed libbladeRF version to 1.7.2
* Thu Mar 23 2017 jengelh@inai.de
- Rename %%soname to %%sover to better reflect its use.
- RPM group fix.
* Thu Mar  9 2017 mpluskal@suse.com
- Update to version 1.4.0
- Cleanup spec file with spec-cleaner
* Fri Feb 19 2016 dl8fcl@t-online.de
- udev_rules_update added for openSUSE
* Sat Aug  1 2015 wk@ire.pw.edu.pl
- updated to release 2015.07
- libbladeRF version 1.4.3
- bladeRF-cli version 1.2.1
* Tue Mar  3 2015 wk@ire.pw.edu.pl
- fixed build on armv7l (openSUSE 13.2)
* Sun Mar  1 2015 wk@ire.pw.edu.pl
- updated to release 2015.02
- libbladeRF version 1.2.1
- bladeRF-cli version 1.1.2
* Sun Aug  3 2014 wk@ire.pw.edu.pl
- updated to git 20140803
* Fri Jul 25 2014 wk@ire.pw.edu.pl
- version 0.16.2 git20140725
* Sun Oct  6 2013 Wojciech Kazubski <wk@ire.pw.edu.pl> - 0.0.20130915-1.1
- git 20130915
- initial spec file.
